@@ -5,7 +5,8 @@ import (
 	"fmt"
 	"time"
 
-	"github.com/deckarep/golang-set"
+	mapset "github.com/deckarep/golang-set"
+	liberr "github.com/konveyor/controller/pkg/error"
 	migapi "github.com/konveyor/mig-controller/pkg/apis/migration/v1alpha1"
 	"github.com/konveyor/mig-controller/pkg/settings"
 	"github.com/pkg/errors"
@@ -22,8 +23,7 @@ import (
 func (t *Task) ensureInitialBackup() (*velero.Backup, error) {
 	backup, err := t.getInitialBackup()
 	if err != nil {
-		log.Trace(err)
-		return nil, err
+		return nil, liberr.Wrap(err)
 	}
 	if backup != nil {
 		return backup, nil
@@ -31,22 +31,21 @@ func (t *Task) ensureInitialBackup() (*velero.Backup, error) {
 
 	client, err := t.getSourceClient()
 	if err != nil {
-		log.Trace(err)
-		return nil, err
+		return nil, liberr.Wrap(err)
 	}
 	newBackup, err := t.buildBackup(client)
 	if err != nil {
-		log.Trace(err)
-		return nil, err
+		return nil, liberr.Wrap(err)
 	}
 	newBackup.Labels[InitialBackupLabel] = t.UID()
+	newBackup.Labels[MigMigrationDebugLabel] = t.Owner.Name
+	newBackup.Labels[MigPlanDebugLabel] = t.Owner.Spec.MigPlanRef.Name
 	newBackup.Spec.IncludedResources = toStringSlice(settings.IncludedInitialResources.Difference(toSet(t.PlanResources.MigPlan.Status.ExcludedResources)))
 	newBackup.Spec.ExcludedResources = toStringSlice(settings.ExcludedInitialResources.Union(toSet(t.PlanResources.MigPlan.Status.ExcludedResources)))
 	delete(newBackup.Annotations, QuiesceAnnotation)
 	err = client.Create(context.TODO(), newBackup)
 	if err != nil {
-		log.Trace(err)
-		return nil, err
+		return nil, liberr.Wrap(err)
 	}
 	return newBackup, nil
 }
@@ -79,8 +78,7 @@ func (t *Task) getInitialBackup() (*velero.Backup, error) {
 func (t *Task) ensureStageBackup() (*velero.Backup, error) {
 	backup, err := t.getStageBackup()
 	if err != nil {
-		log.Trace(err)
-		return nil, err
+		return nil, liberr.Wrap(err)
 	}
 	if backup != nil {
 		return backup, nil
@@ -88,12 +86,11 @@ func (t *Task) ensureStageBackup() (*velero.Backup, error) {
 
 	client, err := t.getSourceClient()
 	if err != nil {
-		log.Trace(err)
-		return nil, err
+		return nil, liberr.Wrap(err)
 	}
 	newBackup, err := t.buildBackup(client)
 	if err != nil {
-		return nil, err
+		return nil, liberr.Wrap(err)
 	}
 	labelSelector := metav1.LabelSelector{
 		MatchLabels: map[string]string{
@@ -101,6 +98,8 @@ func (t *Task) ensureStageBackup() (*velero.Backup, error) {
 		},
 	}
 	newBackup.Labels[StageBackupLabel] = t.UID()
+	newBackup.Labels[MigMigrationDebugLabel] = t.Owner.Name
+	newBackup.Labels[MigPlanDebugLabel] = t.Owner.Spec.MigPlanRef.Name
 	newBackup.Spec.IncludedResources = toStringSlice(settings.IncludedStageResources.Difference(toSet(t.PlanResources.MigPlan.Status.ExcludedResources)))
 	newBackup.Spec.ExcludedResources = toStringSlice(settings.ExcludedStageResources.Union(toSet(t.PlanResources.MigPlan.Status.ExcludedResources)))
 	newBackup.Spec.LabelSelector = &labelSelector
@@ -217,18 +216,15 @@ func (t *Task) buildBackup(client k8sclient.Client) (*velero.Backup, error) {
 	var includeClusterResources *bool = nil
 	annotations, err := t.getAnnotations(client)
 	if err != nil {
-		log.Trace(err)
-		return nil, err
+		return nil, liberr.Wrap(err)
 	}
 	backupLocation, err := t.getBSL()
 	if err != nil {
-		log.Trace(err)
-		return nil, err
+		return nil, liberr.Wrap(err)
 	}
 	snapshotLocation, err := t.getVSL()
 	if err != nil {
-		log.Trace(err)
-		return nil, err
+		return nil, liberr.Wrap(err)
 	}
 	backup := &velero.Backup{
 		ObjectMeta: metav1.ObjectMeta{
@@ -254,8 +250,7 @@ func (t *Task) buildBackup(client k8sclient.Client) (*velero.Backup, error) {
 func (t *Task) deleteBackups() error {
 	client, err := t.getSourceClient()
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 
 	list := velero.BackupList{}
@@ -264,8 +259,7 @@ func (t *Task) deleteBackups() error {
 		k8sclient.MatchingLabels(t.Owner.GetCorrelationLabels()),
 		&list)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 
 	for _, backup := range list.Items {
@@ -279,8 +273,7 @@ func (t *Task) deleteBackups() error {
 			},
 		}
 		if err := client.Create(context.TODO(), request); err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 	}
 
