@@ -20,7 +20,8 @@ import (
 	"fmt"
 	"time"
 
-	"github.com/deckarep/golang-set"
+	mapset "github.com/deckarep/golang-set"
+	liberr "github.com/konveyor/controller/pkg/error"
 	migapi "github.com/konveyor/mig-controller/pkg/apis/migration/v1alpha1"
 	"github.com/konveyor/mig-controller/pkg/settings"
 	"k8s.io/apimachinery/pkg/api/errors"
@@ -32,18 +33,17 @@ func (r *ReconcileMigMigration) migrate(migration *migapi.MigMigration) (time.Du
 	// Ready
 	plan, err := migration.GetPlan(r)
 	if err != nil {
-		return 0, err
+		return 0, liberr.Wrap(err)
 	}
 	if !plan.Status.IsReady() {
 		log.Info("Plan not ready.", "name", migration.Name)
-		return 0, err
+		return 0, liberr.Wrap(err)
 	}
 
 	// Resources
 	planResources, err := plan.GetRefResources(r)
 	if err != nil {
-		log.Trace(err)
-		return 0, err
+		return 0, liberr.Wrap(err)
 	}
 
 	// Started
@@ -73,7 +73,7 @@ func (r *ReconcileMigMigration) migrate(migration *migapi.MigMigration) (time.Du
 
 	// Result
 	migration.Status.Phase = task.Phase
-	migration.Status.Itenerary = task.Itinerary.Name
+	migration.Status.Itinerary = task.Itinerary.Name
 
 	// Completed
 	if task.Phase == Completed {
@@ -114,9 +114,9 @@ func (r *ReconcileMigMigration) migrate(migration *migapi.MigMigration) (time.Du
 func (r *ReconcileMigMigration) getAnnotations(migration *migapi.MigMigration) map[string]string {
 	annotations := make(map[string]string)
 	if migration.Spec.Stage {
-		annotations[StageOrFinalAnnotation] = "stage"
+		annotations[StageOrFinalMigrationAnnotation] = StageMigration
 	} else {
-		annotations[StageOrFinalAnnotation] = "final"
+		annotations[StageOrFinalMigrationAnnotation] = FinalMigration
 	}
 	return annotations
 }
