@@ -1,13 +1,16 @@
 package migmigration
 
 import (
+	"context"
 	"time"
 
-	"github.com/deckarep/golang-set"
+	mapset "github.com/deckarep/golang-set"
 	"github.com/go-logr/logr"
+	liberr "github.com/konveyor/controller/pkg/error"
 	migapi "github.com/konveyor/mig-controller/pkg/apis/migration/v1alpha1"
 	"github.com/konveyor/mig-controller/pkg/compat"
 	"github.com/konveyor/mig-controller/pkg/settings"
+	imagev1 "github.com/openshift/api/image/v1"
 	"github.com/pkg/errors"
 	k8sclient "sigs.k8s.io/controller-runtime/pkg/client"
 )
@@ -63,7 +66,6 @@ const (
 	EnsureStagePodsDeleted          = "EnsureStagePodsDeleted"
 	EnsureStagePodsTerminated       = "EnsureStagePodsTerminated"
 	EnsureAnnotationsDeleted        = "EnsureAnnotationsDeleted"
-	EnsureLabelsDeleted             = "EnsureLabelsDeleted"
 	EnsureMigratedDeleted           = "EnsureMigratedDeleted"
 	DeleteMigrated                  = "DeleteMigrated"
 	DeleteBackups                   = "DeleteBackups"
@@ -80,6 +82,7 @@ const (
 	HasStagePods = 0x02 // Only when stage pods created.
 	HasPVs       = 0x04 // Only when PVs migrated.
 	HasVerify    = 0x08 // Only when the plan has enabled verification
+	HasISs       = 0x10 // Only when ISs migrated
 )
 
 type Itinerary struct {
@@ -98,20 +101,19 @@ var StageItinerary = Itinerary{
 		{phase: EnsureStagePodsFromTemplates, all: HasPVs},
 		{phase: EnsureStagePodsFromOrphanedPVCs, all: HasPVs},
 		{phase: StagePodsCreated, all: HasStagePods},
-		{phase: AnnotateResources, all: HasPVs},
+		{phase: AnnotateResources, any: HasPVs | HasISs},
 		{phase: RestartRestic, all: HasStagePods},
 		{phase: ResticRestarted, all: HasStagePods},
 		{phase: QuiesceApplications, all: Quiesce},
 		{phase: EnsureQuiesced, all: Quiesce},
-		{phase: EnsureStageBackup, all: HasPVs},
-		{phase: StageBackupCreated, all: HasPVs},
-		{phase: EnsureStageBackupReplicated, all: HasPVs},
-		{phase: EnsureStageRestore, all: HasPVs},
-		{phase: StageRestoreCreated, all: HasPVs},
+		{phase: EnsureStageBackup, any: HasPVs | HasISs},
+		{phase: StageBackupCreated, any: HasPVs | HasISs},
+		{phase: EnsureStageBackupReplicated, any: HasPVs | HasISs},
+		{phase: EnsureStageRestore, any: HasPVs | HasISs},
+		{phase: StageRestoreCreated, any: HasPVs | HasISs},
 		{phase: EnsureStagePodsDeleted, all: HasStagePods},
 		{phase: EnsureStagePodsTerminated, all: HasStagePods},
-		{phase: EnsureAnnotationsDeleted, all: HasPVs},
-		{phase: EnsureLabelsDeleted},
+		{phase: EnsureAnnotationsDeleted, any: HasPVs | HasISs},
 		{phase: Completed},
 	},
 }
@@ -130,25 +132,24 @@ var FinalItinerary = Itinerary{
 		{phase: EnsureStagePodsFromTemplates, all: HasPVs},
 		{phase: EnsureStagePodsFromOrphanedPVCs, all: HasPVs},
 		{phase: StagePodsCreated, all: HasStagePods},
-		{phase: AnnotateResources, all: HasPVs},
+		{phase: AnnotateResources, any: HasPVs | HasISs},
 		{phase: RestartRestic, all: HasStagePods},
 		{phase: ResticRestarted, all: HasStagePods},
 		{phase: QuiesceApplications, all: Quiesce},
 		{phase: EnsureQuiesced, all: Quiesce},
-		{phase: EnsureStageBackup, all: HasPVs},
-		{phase: StageBackupCreated, all: HasPVs},
-		{phase: EnsureStageBackupReplicated, all: HasPVs},
-		{phase: EnsureStageRestore, all: HasPVs},
-		{phase: StageRestoreCreated, all: HasPVs},
+		{phase: EnsureStageBackup, any: HasPVs | HasISs},
+		{phase: StageBackupCreated, any: HasPVs | HasISs},
+		{phase: EnsureStageBackupReplicated, any: HasPVs | HasISs},
+		{phase: EnsureStageRestore, any: HasPVs | HasISs},
+		{phase: StageRestoreCreated, any: HasPVs | HasISs},
 		{phase: EnsureStagePodsDeleted, all: HasStagePods},
 		{phase: EnsureStagePodsTerminated, all: HasStagePods},
-		{phase: EnsureAnnotationsDeleted, all: HasPVs},
+		{phase: EnsureAnnotationsDeleted, any: HasPVs | HasISs},
 		{phase: EnsureInitialBackupReplicated},
 		{phase: PostBackupHooks},
 		{phase: PreRestoreHooks},
 		{phase: EnsureFinalRestore},
 		{phase: FinalRestoreCreated},
-		{phase: EnsureLabelsDeleted},
 		{phase: PostRestoreHooks},
 		{phase: Verification, all: HasVerify},
 		{phase: Completed},
@@ -162,7 +163,7 @@ var CancelItinerary = Itinerary{
 		{phase: DeleteBackups},
 		{phase: DeleteRestores},
 		{phase: EnsureStagePodsDeleted, all: HasStagePods},
-		{phase: EnsureAnnotationsDeleted, all: HasPVs},
+		{phase: EnsureAnnotationsDeleted, any: HasPVs | HasISs},
 		{phase: DeleteMigrated},
 		{phase: EnsureMigratedDeleted},
 		{phase: UnQuiesceApplications, all: Quiesce},
@@ -176,7 +177,7 @@ var FailedItinerary = Itinerary{
 	Steps: []Step{
 		{phase: MigrationFailed},
 		{phase: EnsureStagePodsDeleted, all: HasStagePods},
-		{phase: EnsureAnnotationsDeleted, all: HasPVs},
+		{phase: EnsureAnnotationsDeleted, any: HasPVs | HasISs},
 		{phase: DeleteMigrated},
 		{phase: EnsureMigratedDeleted},
 		{phase: UnQuiesceApplications, all: Quiesce},
@@ -243,31 +244,35 @@ type Task struct {
 func (t *Task) Run() error {
 	t.Log.Info("[RUN]", "stage", t.stage(), "phase", t.Phase)
 
-	t.init()
+	err := t.init()
+	if err != nil {
+		return err
+	}
 
 	// Run the current phase.
 	switch t.Phase {
 	case Created, Started:
-		t.next()
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
+		}
 	case Prepare:
 		err := t.ensureStagePodsDeleted()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		err = t.deleteAnnotations()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
+		}
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
 		}
-		t.next()
 	case EnsureCloudSecretPropagated:
 		count := 0
 		for _, cluster := range t.getBothClusters() {
 			propagated, err := t.veleroPodCredSecretPropagated(cluster)
 			if err != nil {
-				log.Trace(err)
-				return err
+				return liberr.Wrap(err)
 			}
 			if propagated {
 				count++
@@ -276,35 +281,38 @@ func (t *Task) Run() error {
 			}
 		}
 		if count == 2 {
-			t.next()
+			if err = t.next(); err != nil {
+				return liberr.Wrap(err)
+			}
 		} else {
 			t.Requeue = PollReQ
 		}
 	case PreBackupHooks:
 		status, err := t.runHooks(migapi.PreBackupHookPhase)
 		if err != nil {
-			log.Trace(err)
 			t.fail(PreBackupHooksFailed, []string{err.Error()})
-			return err
+			return liberr.Wrap(err)
 		}
 		if status {
-			t.next()
+			if err = t.next(); err != nil {
+				return liberr.Wrap(err)
+			}
 		} else {
 			t.Requeue = NoReQ
 		}
 	case EnsureInitialBackup:
 		_, err := t.ensureInitialBackup()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		t.Requeue = NoReQ
-		t.next()
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
+		}
 	case InitialBackupCreated:
 		backup, err := t.getInitialBackup()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		if backup == nil {
 			return errors.New("Backup not found")
@@ -314,7 +322,9 @@ func (t *Task) Run() error {
 			if len(reasons) > 0 {
 				t.fail(InitialBackupFailed, reasons)
 			} else {
-				t.next()
+				if err = t.next(); err != nil {
+					return liberr.Wrap(err)
+				}
 			}
 		} else {
 			t.Requeue = NoReQ
@@ -322,106 +332,116 @@ func (t *Task) Run() error {
 	case AnnotateResources:
 		err := t.annotateStageResources()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
+		}
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
 		}
-		t.next()
 	case EnsureStagePodsFromRunning:
 		err := t.ensureStagePodsFromRunning()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		t.Requeue = NoReQ
-		t.next()
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
+		}
 	case EnsureStagePodsFromTemplates:
 		err := t.ensureStagePodsFromTemplates()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		t.Requeue = NoReQ
-		t.next()
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
+		}
 	case EnsureStagePodsFromOrphanedPVCs:
 		err := t.ensureStagePodsFromOrphanedPVCs()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		t.Requeue = NoReQ
-		t.next()
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
+		}
 	case StagePodsCreated:
 		report, err := t.ensureStagePodsStarted()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		if report.failed {
 			t.fail(StagePodsFailed, report.reasons)
 			break
 		}
 		if report.started {
-			t.next()
+			if err = t.next(); err != nil {
+				return liberr.Wrap(err)
+			}
 		} else {
 			t.Requeue = NoReQ
 		}
 	case RestartRestic:
 		err := t.restartResticPods()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		t.Requeue = PollReQ
-		t.next()
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
+		}
 	case ResticRestarted:
 		started, err := t.haveResticPodsStarted()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		if started {
-			t.next()
+			if err = t.next(); err != nil {
+				return liberr.Wrap(err)
+			}
 		} else {
 			t.Requeue = PollReQ
 		}
 	case QuiesceApplications:
 		err := t.quiesceApplications()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
+		}
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
 		}
-		t.next()
 	case EnsureQuiesced:
 		quiesced, err := t.ensureQuiescedPodsTerminated()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		if quiesced {
-			t.next()
+			if err = t.next(); err != nil {
+				return liberr.Wrap(err)
+			}
 		} else {
 			t.Requeue = PollReQ
 		}
 	case UnQuiesceApplications:
 		err := t.unQuiesceApplications()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
+		}
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
 		}
-		t.next()
 	case EnsureStageBackup:
 		_, err := t.ensureStageBackup()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		t.Requeue = NoReQ
-		t.next()
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
+		}
 	case StageBackupCreated:
 		backup, err := t.getStageBackup()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		if backup == nil {
 			return errors.New("Backup not found")
@@ -431,7 +451,9 @@ func (t *Task) Run() error {
 			if len(reasons) > 0 {
 				t.fail(StageBackupFailed, reasons)
 			} else {
-				t.next()
+				if err = t.next(); err != nil {
+					return liberr.Wrap(err)
+				}
 			}
 		} else {
 			t.Requeue = NoReQ
@@ -439,59 +461,61 @@ func (t *Task) Run() error {
 	case EnsureStageBackupReplicated:
 		backup, err := t.getStageBackup()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		if backup == nil {
 			return errors.New("Backup not found")
 		}
 		replicated, err := t.isBackupReplicated(backup)
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		if replicated {
-			t.next()
+			if err = t.next(); err != nil {
+				return liberr.Wrap(err)
+			}
 		} else {
 			t.Requeue = NoReQ
 		}
 	case PostBackupHooks:
 		status, err := t.runHooks(migapi.PostBackupHookPhase)
 		if err != nil {
-			log.Trace(err)
 			t.fail(PostBackupHooksFailed, []string{err.Error()})
-			return err
+			return liberr.Wrap(err)
 		}
 		if status {
-			t.next()
+			if err = t.next(); err != nil {
+				return liberr.Wrap(err)
+			}
 		} else {
 			t.Requeue = NoReQ
 		}
 	case PreRestoreHooks:
 		status, err := t.runHooks(migapi.PreRestoreHookPhase)
 		if err != nil {
-			log.Trace(err)
 			t.fail(PreRestoreHooksFailed, []string{err.Error()})
-			return err
+			return liberr.Wrap(err)
 		}
 		if status {
-			t.next()
+			if err = t.next(); err != nil {
+				return liberr.Wrap(err)
+			}
 		} else {
 			t.Requeue = NoReQ
 		}
 	case EnsureStageRestore:
 		_, err := t.ensureStageRestore()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		t.Requeue = NoReQ
-		t.next()
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
+		}
 	case StageRestoreCreated:
 		restore, err := t.getStageRestore()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		if restore == nil {
 			return errors.New("Restore not found")
@@ -502,7 +526,9 @@ func (t *Task) Run() error {
 			if len(reasons) > 0 {
 				t.fail(StageRestoreFailed, reasons)
 			} else {
-				t.next()
+				if err = t.next(); err != nil {
+					return liberr.Wrap(err)
+				}
 			}
 		} else {
 			t.Requeue = NoReQ
@@ -510,18 +536,20 @@ func (t *Task) Run() error {
 	case EnsureStagePodsDeleted:
 		err := t.ensureStagePodsDeleted()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
+		}
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
 		}
-		t.next()
 	case EnsureStagePodsTerminated:
 		terminated, err := t.ensureStagePodsTerminated()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		if terminated {
-			t.next()
+			if err = t.next(); err != nil {
+				return liberr.Wrap(err)
+			}
 		} else {
 			t.Requeue = PollReQ
 		}
@@ -529,60 +557,51 @@ func (t *Task) Run() error {
 		if !t.keepAnnotations() {
 			err := t.deleteAnnotations()
 			if err != nil {
-				log.Trace(err)
-				return err
+				return liberr.Wrap(err)
 			}
 		}
-		t.next()
-	case EnsureLabelsDeleted:
-		if !t.keepAnnotations() {
-			err := t.deleteLabels()
-			if err != nil {
-				log.Trace(err)
-				return err
-			}
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
 		}
-		t.next()
 	case EnsureInitialBackupReplicated:
 		backup, err := t.getInitialBackup()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		if backup == nil {
 			return errors.New("Backup not found")
 		}
 		replicated, err := t.isBackupReplicated(backup)
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		if replicated {
-			t.next()
+			if err = t.next(); err != nil {
+				return liberr.Wrap(err)
+			}
 		} else {
 			t.Requeue = NoReQ
 		}
 	case EnsureFinalRestore:
 		backup, err := t.getInitialBackup()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		if backup == nil {
 			return errors.New("Backup not found")
 		}
 		_, err = t.ensureFinalRestore()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		t.Requeue = NoReQ
-		t.next()
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
+		}
 	case FinalRestoreCreated:
 		restore, err := t.getFinalRestore()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		if restore == nil {
 			return errors.New("Restore not found")
@@ -592,7 +611,9 @@ func (t *Task) Run() error {
 			if len(reasons) > 0 {
 				t.fail(FinalRestoreFailed, reasons)
 			} else {
-				t.next()
+				if err = t.next(); err != nil {
+					return liberr.Wrap(err)
+				}
 			}
 		} else {
 			t.Requeue = NoReQ
@@ -600,23 +621,25 @@ func (t *Task) Run() error {
 	case PostRestoreHooks:
 		status, err := t.runHooks(migapi.PostRestoreHookPhase)
 		if err != nil {
-			log.Trace(err)
 			t.fail(PostRestoreHooksFailed, []string{err.Error()})
-			return err
+			return liberr.Wrap(err)
 		}
 		if status {
-			t.next()
+			if err = t.next(); err != nil {
+				return liberr.Wrap(err)
+			}
 		} else {
 			t.Requeue = NoReQ
 		}
 	case Verification:
 		completed, err := t.VerificationCompleted()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		if completed {
-			t.next()
+			if err = t.next(); err != nil {
+				return liberr.Wrap(err)
+			}
 		} else {
 			t.Requeue = PollReQ
 		}
@@ -629,11 +652,15 @@ func (t *Task) Run() error {
 			Message:  CancelInProgressMessage,
 			Durable:  true,
 		})
-		t.next()
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
+		}
 
 	case MigrationFailed:
 		if Settings.Migration.FailureRollback {
-			t.next()
+			if err = t.next(); err != nil {
+				return liberr.Wrap(err)
+			}
 		} else {
 			t.Phase = Completed
 		}
@@ -641,33 +668,37 @@ func (t *Task) Run() error {
 	case DeleteMigrated:
 		err := t.deleteMigrated()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
+		}
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
 		}
-		t.next()
 	case EnsureMigratedDeleted:
 		deleted, err := t.ensureMigratedResourcesDeleted()
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		if deleted {
-			t.next()
+			if err = t.next(); err != nil {
+				return liberr.Wrap(err)
+			}
 		} else {
 			t.Requeue = PollReQ
 		}
 	case DeleteBackups:
 		if err := t.deleteBackups(); err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
+		}
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
 		}
-		t.next()
 	case DeleteRestores:
 		if err := t.deleteRestores(); err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
+		}
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
 		}
-		t.next()
 	case Canceled:
 		t.Owner.Status.DeleteCondition(Canceling)
 		t.Owner.Status.SetCondition(migapi.Condition{
@@ -678,11 +709,15 @@ func (t *Task) Run() error {
 			Message:  CanceledMessage,
 			Durable:  true,
 		})
-		t.next()
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
+		}
 	case Completed:
 	default:
 		t.Requeue = NoReQ
-		t.next()
+		if err = t.next(); err != nil {
+			return liberr.Wrap(err)
+		}
 	}
 
 	if t.Phase == Completed {
@@ -694,7 +729,7 @@ func (t *Task) Run() error {
 }
 
 // Initialize.
-func (t *Task) init() {
+func (t *Task) init() error {
 	t.Requeue = FastReQ
 	if t.failed() {
 		t.Itinerary = FailedItinerary
@@ -705,10 +740,16 @@ func (t *Task) init() {
 	} else {
 		t.Itinerary = FinalItinerary
 	}
-	if t.Owner.Status.Itenerary != t.Itinerary.Name {
+	if t.Owner.Status.Itinerary != t.Itinerary.Name {
 		t.Phase = t.Itinerary.Steps[0].phase
 	}
-	if t.stage() && !t.hasPVs() {
+
+	hasImageStreams, err := t.hasImageStreams()
+	if err != nil {
+		return err
+	}
+
+	if t.stage() && (!t.hasPVs() && !hasImageStreams) {
 		t.Owner.Status.SetCondition(migapi.Condition{
 			Type:     StageNoOp,
 			Status:   True,
@@ -717,10 +758,11 @@ func (t *Task) init() {
 			Durable:  true,
 		})
 	}
+	return nil
 }
 
 // Advance the task to the next phase.
-func (t *Task) next() {
+func (t *Task) next() error {
 	current := -1
 	for i, step := range t.Itinerary.Steps {
 		if step.phase != t.Phase {
@@ -731,56 +773,78 @@ func (t *Task) next() {
 	}
 	if current == -1 {
 		t.Phase = Completed
-		return
+		return nil
 	}
 	for n := current + 1; n < len(t.Itinerary.Steps); n++ {
 		next := t.Itinerary.Steps[n]
-		if !t.allFlags(next) {
+		flag, err := t.allFlags(next)
+		if err != nil {
+			return liberr.Wrap(err)
+		}
+		if !flag {
 			continue
 		}
-		if !t.anyFlags(next) {
+		flag, err = t.anyFlags(next)
+		if err != nil {
+			return liberr.Wrap(err)
+		}
+		if !flag {
 			continue
 		}
 		t.Phase = next.phase
-		return
+		return nil
 	}
 	t.Phase = Completed
+	return nil
 }
 
 // Evaluate `all` flags.
-func (t *Task) allFlags(step Step) bool {
+func (t *Task) allFlags(step Step) (bool, error) {
 	if step.all&HasPVs != 0 && !t.hasPVs() {
-		return false
+		return false, nil
 	}
 	if step.all&HasStagePods != 0 && !t.Owner.Status.HasCondition(StagePodsCreated) {
-		return false
+		return false, nil
 	}
 	if step.all&Quiesce != 0 && !t.quiesce() {
-		return false
+		return false, nil
 	}
 	if step.all&HasVerify != 0 && !t.hasVerify() {
-		return false
+		return false, nil
+	}
+	hasImageStream, err := t.hasImageStreams()
+	if err != nil {
+		return false, liberr.Wrap(err)
+	}
+	if step.all&HasISs != 0 && hasImageStream {
+		return false, nil
 	}
 
-	return true
+	return true, nil
 }
 
 // Evaluate `any` flags.
-func (t *Task) anyFlags(step Step) bool {
+func (t *Task) anyFlags(step Step) (bool, error) {
 	if step.any&HasPVs != 0 && t.hasPVs() {
-		return true
+		return true, nil
 	}
 	if step.any&HasStagePods != 0 && t.Owner.Status.HasCondition(StagePodsCreated) {
-		return true
+		return true, nil
 	}
 	if step.any&Quiesce != 0 && t.quiesce() {
-		return true
+		return true, nil
 	}
 	if step.any&HasVerify != 0 && t.hasVerify() {
-		return true
+		return true, nil
 	}
-
-	return step.any == uint8(0)
+	hasImageStream, err := t.hasImageStreams()
+	if err != nil {
+		return false, liberr.Wrap(err)
+	}
+	if step.any&HasISs != 0 && hasImageStream {
+		return true, nil
+	}
+	return step.any == uint8(0), nil
 }
 
 // Phase fail.
@@ -896,6 +960,27 @@ func (t *Task) hasPVs() bool {
 	return false
 }
 
+// Get whether the associated plan has imagestreams to be migrated
+func (t *Task) hasImageStreams() (bool, error) {
+	client, err := t.getSourceClient()
+	if err != nil {
+		log.Trace(err)
+		return false, err
+	}
+	for _, ns := range t.sourceNamespaces() {
+		imageStreamList := imagev1.ImageStreamList{}
+		err := client.List(context.Background(), &k8sclient.ListOptions{Namespace: ns}, &imageStreamList)
+		if err != nil {
+			log.Trace(err)
+			return false, err
+		}
+		if len(imageStreamList.Items) > 0 {
+			return true, nil
+		}
+	}
+	return false, nil
+}
+
 // Get whether the verification is desired
 func (t *Task) hasVerify() bool {
 	return t.Owner.Spec.Verify
@@ -914,8 +999,7 @@ func (t *Task) getBothClients() ([]k8sclient.Client, error) {
 	for _, cluster := range t.getBothClusters() {
 		client, err := cluster.GetClient(t.Client)
 		if err != nil {
-			log.Trace(err)
-			return nil, err
+			return nil, liberr.Wrap(err)
 		}
 		list = append(list, client)
 	}
@@ -927,8 +1011,7 @@ func (t *Task) getBothClients() ([]k8sclient.Client, error) {
 func (t *Task) getBothClientsWithNamespaces() ([]k8sclient.Client, [][]string, error) {
 	clientList, err := t.getBothClients()
 	if err != nil {
-		log.Trace(err)
-		return nil, nil, err
+		return nil, nil, liberr.Wrap(err)
 	}
 	namespaceList := [][]string{t.sourceNamespaces(), t.destinationNamespaces()}
 
