@@ -3,6 +3,7 @@ package migplan
 import (
 	"context"
 
+	liberr "github.com/konveyor/controller/pkg/error"
 	migapi "github.com/konveyor/mig-controller/pkg/apis/migration/v1alpha1"
 	kapi "k8s.io/api/core/v1"
 	k8sclient "sigs.k8s.io/controller-runtime/pkg/client"
@@ -19,16 +20,14 @@ func (r ReconcileMigPlan) ensureMigRegistries(plan *migapi.MigPlan) error {
 	}
 	storage, err := plan.GetStorage(r)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 	if storage == nil || !storage.Status.IsReady() {
 		return nil
 	}
 	clusters, err := r.planClusters(plan)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 
 	for _, cluster := range clusters {
@@ -37,43 +36,37 @@ func (r ReconcileMigPlan) ensureMigRegistries(plan *migapi.MigPlan) error {
 		}
 		client, err = cluster.GetClient(r)
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 
 		// Get cluster specific registry image
 		registryImage, err := cluster.GetRegistryImage(client)
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 
 		// Migration Registry Secret
 		secret, err := r.ensureRegistrySecret(client, plan, storage)
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 
 		// Migration Registry ImageStream
 		err = r.ensureRegistryImageStream(client, plan, secret, registryImage)
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 
 		// Migration Registry DeploymentConfig
 		err = r.ensureRegistryDC(client, plan, storage, secret, registryImage)
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 
 		// Migration Registry Service
 		err = r.ensureRegistryService(client, plan, secret)
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 
 		nEnsured++
@@ -126,19 +119,16 @@ func (r ReconcileMigPlan) ensureRegistrySecret(client k8sclient.Client, plan *mi
 func (r ReconcileMigPlan) ensureRegistryImageStream(client k8sclient.Client, plan *migapi.MigPlan, secret *kapi.Secret, registryImage string) error {
 	newImageStream, err := plan.BuildRegistryImageStream(secret.GetName(), registryImage)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 	foundImageStream, err := plan.GetRegistryImageStream(client)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 	if foundImageStream == nil {
 		err = client.Create(context.TODO(), newImageStream)
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		return nil
 	}
@@ -148,8 +138,7 @@ func (r ReconcileMigPlan) ensureRegistryImageStream(client k8sclient.Client, pla
 	plan.UpdateRegistryImageStream(foundImageStream, registryImage)
 	err = client.Update(context.TODO(), foundImageStream)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 
 	return nil
@@ -160,31 +149,27 @@ func (r ReconcileMigPlan) ensureRegistryDC(client k8sclient.Client, plan *migapi
 	storage *migapi.MigStorage, secret *kapi.Secret, registryImage string) error {
 
 	name := secret.GetName()
-	dirName := plan.GetName() + "-registry-" + string(plan.UID)
+	dirName := storage.GetName() + "-registry-" + string(storage.UID)
 
 	// Get Proxy Env Vars for DC
 	proxySecret, err := plan.GetRegistryProxySecret(client)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 
 	//Construct Registry DC
 	newDC, err := plan.BuildRegistryDC(storage, proxySecret, name, dirName, registryImage)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 	foundDC, err := plan.GetRegistryDC(client)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 	if foundDC == nil {
 		err = client.Create(context.TODO(), newDC)
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		return nil
 	}
@@ -194,8 +179,7 @@ func (r ReconcileMigPlan) ensureRegistryDC(client k8sclient.Client, plan *migapi
 	plan.UpdateRegistryDC(storage, foundDC, proxySecret, name, dirName, registryImage)
 	err = client.Update(context.TODO(), foundDC)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 
 	return nil
@@ -206,19 +190,16 @@ func (r ReconcileMigPlan) ensureRegistryService(client k8sclient.Client, plan *m
 	name := secret.GetName()
 	newService, err := plan.BuildRegistryService(name)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 	foundService, err := plan.GetRegistryService(client)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 	if foundService == nil {
 		err = client.Create(context.TODO(), newService)
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		return nil
 	}
@@ -228,8 +209,7 @@ func (r ReconcileMigPlan) ensureRegistryService(client k8sclient.Client, plan *m
 	plan.UpdateRegistryService(foundService, name)
 	err = client.Update(context.TODO(), foundService)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 
 	return nil
